@@ -1,6 +1,7 @@
 use strict; use warnings;
 package Lingy::Lang::Var;
 
-use base 'Lingy::Lang::ScalarClass';
+use Lingy::Common;
+use base SCALARTYPE;
 
 1;
