@@ -54,9 +54,9 @@ sub read_str {
 sub read_form {
     my ($self) = @_;
     local $_ = $self->{tokens}[0];
-    /^\($/ ? $self->read_list('Lingy::Lang::List', ')') :
-    /^\[$/ ? $self->read_list('Lingy::Lang::Vector', ']') :
-    /^\{$/ ? $self->read_hash_map('Lingy::Lang::HashMap', '}') :
+    /^\($/ ? $self->read_list(LIST, ')') :
+    /^\[$/ ? $self->read_list(VECTOR, ']') :
+    /^\{$/ ? $self->read_hash_map(HASHMAP, '}') :
     /^'$/ ? $self->read_quote('quote') :
     /^`$/ ? $self->read_quote('quasiquote') :
     /^~$/ ? $self->read_quote('unquote') :
@@ -190,7 +190,7 @@ sub with_meta {
         symbol('with-meta'),
         $form,
         $meta,
-    ], 'Lingy::Lang::List';
+    ], LIST;
 }
 
 1;
